@@ -11,7 +11,7 @@ from preseem.model_sync import sync_preseem_model, ElementSyncItem
 from preseem_protobuf.model.common_pb2 import ElementStatus
 from preseem_protobuf.model.account_pb2 import AccountStatus
 from preseem_protobuf.model.common_pb2 import AccountType
-from preseem.source_model import Attachment, Olt, Router, Service
+from preseem.source_model import Attachment, AccessPoint, Olt, Router, Service
 
 Account = namedtuple('Account', ('id', 'type', 'status', 'name', 'first_name', 'last_name'))
 Package = namedtuple('Package', ('id', 'name', 'download_rate', 'upload_rate'))
@@ -1284,6 +1284,9 @@ class TestModelSync(unittest.TestCase):
     async def checkSourceOlt(self, sobj, deleted=False):
         return await self.checkSourceElement(sobj, ElementRole.OLT, deleted=deleted)
 
+    async def checkSourceAP(self, sobj, deleted=False):
+        return await self.checkSourceElement(sobj, ElementRole.AP, deleted=deleted)
+
     def test_router_create(self):
         """An Router is created in the model."""
         async def test():
@@ -1425,3 +1428,30 @@ class TestModelSync(unittest.TestCase):
             await self.checkSourceRouter(router, deleted=True)
         self._await(test())
 
+    def test_ap(self):
+        """APs are handled properly the "modern" way in the model, the same way routers are."""
+        async def test():
+            # create an AP
+            ap = AccessPoint('ap01', host='192.0.2.1', name='AP 1', site='Site 1')
+            aps = {'ap01': ap}
+            await sync_preseem_model(self.model, self.company.uuid, 'test_source', None, [], aps=aps)
+            await self.checkSourceAP(ap)
+
+            # add a router so we can test any interactions between them
+            router = Router('router01', host='192.0.2.254', name='Router 1', site='Site 1')
+            routers = {'router01': router}
+            await sync_preseem_model(self.model, self.company.uuid, 'test_source', None, [], routers=routers)
+            await self.checkSourceAP(ap)
+            await self.checkSourceRouter(router)
+
+            await sync_preseem_model(self.model, self.company.uuid, 'test_source', None, [], aps=aps, routers=routers)
+            await self.checkSourceAP(ap)
+            await self.checkSourceRouter(router)
+
+            # Delete the router and update the AP
+            ap.host = '192.0.2.2'
+            await sync_preseem_model(self.model, self.company.uuid, 'test_source', None, [], aps=aps, routers={})
+            await self.checkSourceAP(ap)
+            await self.checkSourceRouter(router, deleted=True)
+        self._await(test())
+
